[svn-commits] rizzo: branch rizzo/astobj2 r48537 - /team/rizzo/astobj2/channels/chan_sip.c

svn-commits at lists.digium.com svn-commits at lists.digium.com
Sun Dec 17 01:02:35 MST 2006


Author: rizzo
Date: Sun Dec 17 02:02:34 2006
New Revision: 48537

URL: http://svn.digium.com/view/asterisk?view=rev&rev=48537
Log:
rename handle_request() to handle_incoming() because
that's what it does.


Modified:
    team/rizzo/astobj2/channels/chan_sip.c

Modified: team/rizzo/astobj2/channels/chan_sip.c
URL: http://svn.digium.com/view/asterisk/team/rizzo/astobj2/channels/chan_sip.c?view=diff&rev=48537&r1=48536&r2=48537
==============================================================================
--- team/rizzo/astobj2/channels/chan_sip.c (original)
+++ team/rizzo/astobj2/channels/chan_sip.c Sun Dec 17 02:02:34 2006
@@ -57,7 +57,7 @@
  * sipsock_read(). This function parses the packet and matches an existing
  * dialog or starts a new SIP dialog.
  * 
  * sipsock_read sends the packet to handle_request(), that parses a bit more.
  * if it's a response to an outbound request, it's sent to handle_response().
  * If it is a request, handle_request sends it to one of a list of functions
  * depending on the request type - INVITE, OPTIONS, REFER, BYE, CANCEL etc
@@ -1634,7 +1634,7 @@
 static void build_rpid(struct sip_pvt *p);
 
 /*------Request handling functions */
-static int handle_request(struct sip_pvt *p, struct sip_request *req, struct sockaddr_in *sin, int *recount, int *nounlock);
+static int handle_incoming(struct sip_pvt *p, struct sip_request *req, struct sockaddr_in *sin, int *recount, int *nounlock);
 static int handle_request_invite(struct sip_pvt *p, struct sip_request *req, int debug, int seqno, struct sockaddr_in *sin, int *recount, char *e);
 static int handle_request_refer(struct sip_pvt *p, struct sip_request *req, int debug, int seqno, int *nounlock);
 static int handle_request_bye(struct sip_pvt *p, struct sip_request *req);
@@ -15096,7 +15096,7 @@
  * -1 on error (trapped by the caller)
  * possibly other values as well.
  */
-static int handle_request(struct sip_pvt *p, struct sip_request *req, struct sockaddr_in *sin, int *recount, int *nounlock)
+static int handle_incoming(struct sip_pvt *p, struct sip_request *req, struct sockaddr_in *sin, int *recount, int *nounlock)
 {
 	/* Called with p->lock held, as well as p->owner->lock if appropriate, keeping things
 	   relatively static */
@@ -15293,7 +15293,7 @@
  * Read data from SIP socket. Called from the do_monitor() thread in ast_io_wait()
  * \return 1 on error, 0 on success
  * \note sipsock_read locks the owner channel while we are processing the SIP message
  * \note Successful messages is connected to SIP call and forwarded to handle_request() 
 */
 static int sipsock_read(int *id, int fd, short events, void *ignore)
 {
@@ -15432,7 +15432,7 @@
 	append_history(p, "Rx", "%s / %s / %s", req.data, get_header(&req, "CSeq"), req.rlPart2);
 
 	nounlock = 0;
-	if (handle_request(p, &req, &sin, &recount, &nounlock)) {
+	if (handle_incoming(p, &req, &sin, &recount, &nounlock)) {
 		/* Request failed */
 		if (option_debug)
 			ast_log(LOG_DEBUG, "SIP message could not be handled, bad request: %-70.70s\n", p->callid[0] ? p->callid : "<no callid>");
@@ -57,7 +57,7 @@
  * dialog or starts a new SIP dialog.
  * 
- * sipsock_read sends the packet to handle_request(), that parses a bit more.
+ * sipsock_read sends the packet to handle_incoming(), that parses a bit more.
  * if it's a response to an outbound request, it's sent to handle_response().
  * If it is a request, handle_request sends it to one of a list of functions
@@ -15293,7 +15293,7 @@
  * \return 1 on error, 0 on success
  * \note sipsock_read locks the owner channel while we are processing the SIP message
- * \note Successful messages is connected to SIP call and forwarded to handle_request() 
+ * \note Successful messages is connected to SIP call and forwarded to handle_incoming() 
 */
 static int sipsock_read(int *id, int fd, short events, void *ignore)



More information about the svn-commits mailing list